"use strict";

var slopeBlockPreviewManager = function () {
  var DEFAULT_MAIN_COLOR = '#ffffff';
  var DEFAULT_FONT_COLOR = '#404040';

  function createSlopeBlock(el, children) {
    return el('div', {
      className: 'slope-block',
      style: {
        background: DEFAULT_MAIN_COLOR,
        color: DEFAULT_FONT_COLOR
      }
    }, children);
  }

  function createSlopeReservationSection(el, children) {
    return el('div', {
      className: ['slope-reservation-section-container']
    }, children);
  }

  function createSlopeReservationDates(el) {
    return el('div', {
      className: ['slope-reservation-dates']
    }, [createSlopeReservationSection(el, createSlopeArrival(el)), createSlopeReservationSection(el, createSlopeDeparture(el))]);
  }

  function createSlopeArrival(el) {
    var today = new Date();
    return el('div', {
      className: 'slope-check-in-wrapper'
    }, [el('span', {
      className: 'slope-check-in-label'
    }, 'Check-in'), el('span', {
      className: 'slope-check-in-date'
    }, today.getDate() + ' Ago, ' + today.getFullYear())]);
  }

  function createSlopeDeparture(el) {
    var today = new Date();
    return el('div', {
      className: 'slope-check-out-wrapper'
    }, [el('span', {
      className: 'slope-check-out-label'
    }, 'Check-out'), el('span', {
      className: 'slope-check-out-date'
    }, today.getDate() + 1 + ' Ago, ' + today.getFullYear())]);
  }

  function createSlopeVerticalDivider(el) {
    return el('div', {
      className: 'slope-vertical-divider'
    });
  }

  function createSlopeGuestsAndButtonContainer(el) {
    return el('div', {
      className: 'slope-guests-and-button-container'
    }, [createSlopeReservationSection(el, [createSlopeGuests(el)]), createSlopeSubmitButton(el)]);
  }

  function createSlopeRooms(el) {
    return el('div', {
      className: 'slope-rooms-count-container'
    }, [el('span', {
      className: 'slope-rooms-label'
    }, 'Stanze'), el('span', {
      className: 'slope-rooms-count'
    }, '1')]);
  }

  function createSlopeGuests(el) {
    return el('div', {
      className: 'slope-guests-wrapper'
    }, [createSlopeRooms(el), el('div', {
      className: 'slope-guests-count-container'
    }, [el('span', {
      className: 'slope-guests-label'
    }, 'Ospiti'), el('span', {
      className: 'slope-adults-count'
    }, '2'), el('span', {
      className: 'slope-guests-adults'
    }, ' Adulti'), el('span', {
      className: 'slope-children-count'
    }, ' 0'), el('span', {
      className: 'slope-guests-children'
    }, ' Bambini')])]);
  }

  function createSlopeSubmitButton(el) {
    return el('div', {
      className: 'slope-reservation-section-container slope-submit-section'
    }, [el('input', {
      className: 'slope-reservation-submit',
      type: 'submit',
      value: 'Prenota ora',
      style: {
        background: DEFAULT_FONT_COLOR,
        color: DEFAULT_MAIN_COLOR
      }
    })]);
  }

  function createSlopeLanguageSelect(el, languages, props) {
    return el('select', {
      className: 'slope-block-language-select',
      selectedIndex: languages.indexOf(props.attributes.lang),
      style: {
        fontSize: '10px !important',
        height: '30px !important',
        width: '30px !important',
        minWidth: 'none !important'
      },
      onChange: function onChange() {
        // Find a cleaner way to not use document.activeElement
        props.setAttributes({
          lang: document.activeElement.options[document.activeElement.selectedIndex].value
        });
      }
    }, languages.map(function (lang) {
      return el('option', {
        value: lang,
        selected: lang === props.attributes.lang
      }, lang.toUpperCase());
    }));
  }

  return {
    createSlopeBlock: createSlopeBlock,
    createSlopeReservationDates: createSlopeReservationDates,
    createSlopeVerticalDivider: createSlopeVerticalDivider,
    createSlopeGuestsAndButtonContainer: createSlopeGuestsAndButtonContainer,
    createSlopeLanguageSelect: createSlopeLanguageSelect
  };
}();