"use strict";

var SLOPE_NAME_PROTOTYPES = {
  ADULTS: "reservation[guestCounts][__name__][adults]",
  CHILDREN: "reservation[guestCounts][__name__][childrenAges][__childrenAgesName__]"
};

function SlopeRoom(index, $element, adultsInput, guestsWrapper) {
  this.index = index;
  this.adultsCount = 2;
  this.childrenCount = 0;
  this.adultsInput = adultsInput;
  this.guestsWrapper = guestsWrapper;
  this.$element = null;

  this.update = function () {
    var adultsInput = this.$element.find('[data-sync-trigger="adults"]');
    adultsInput.val(this.adultsCount);
    var childrenInput = this.$element.find('[data-sync-trigger="children"]');
    childrenInput.val(this.childrenCount);
    this.adultsInput.val(this.adultsCount);
  };

  this.reset = function () {
    this.adultsCount = 2;
    this.childrenCount = 0;
    this.update();
  };

  if (index > 0) {
    // The element is not the first so we have to clone the first one is not passed this means we have to clone one
    var clone = $element.last().clone();
    clone.insertBefore($element.parent().find('[data-separator="buttons"]'));
    this.$element = clone;
  } else {
    this.$element = $element;
  }

  this.adultsInput.attr('name', SLOPE_NAME_PROTOTYPES.ADULTS.replace(new RegExp('__name__', 'g'), this.index));
  var roomLabel = this.$element.find('[data-label="room"]');
  roomLabel.text(roomLabel.text().replace(this.index, this.index + 1));
  this.reset();
  var self = this;
  this.$element.find('[data-increment="adults"]').on('click', function () {
    self.incrementAdults();
  });
  this.$element.find('[data-decrement="adults"]').on('click', function () {
    self.decrementAdults();
  });
  this.$element.find('[data-increment="children"]').on('click', function () {
    self.incrementChildren();
  });
  this.$element.find('[data-decrement="children"]').on('click', function () {
    self.decrementChildren();
  });

  this.incrementAdults = function () {
    this.adultsCount += this.adultsCount < 99 ? 1 : 0;
    var input = this.$element.find('[data-sync-trigger="adults"]');
    input.val(this.adultsCount);
  };

  this.decrementAdults = function () {
    this.adultsCount -= this.adultsCount > 1 ? 1 : 0;
    var input = this.$element.find('[data-sync-trigger="adults"]');
    input.val(this.adultsCount);
  };

  this.incrementChildren = function () {
    this.childrenCount += this.childrenCount < 99 ? 1 : 0;
    var input = this.guestsWrapper.find('[data-input="children"]').first();
    var clone = input.clone();
    var name = SLOPE_NAME_PROTOTYPES.CHILDREN;
    name = name.replace(new RegExp('__name__', 'g'), this.index);
    name = name.replace(new RegExp('__childrenAgesName__', 'g'), this.childrenCount);
    clone.attr('name', name);
    clone.appendTo(this.guestsWrapper);
    var stepperInput = this.$element.find('[data-sync-trigger="children"]');
    stepperInput.val(this.childrenCount);
  };

  this.decrementChildren = function () {
    this.childrenCount -= this.childrenCount > 0 ? 1 : 0;
    this.guestsWrapper.find('[data-input="children"][name]').first().remove();
    var stepperInput = this.$element.find('[data-sync-trigger="children"]');
    stepperInput.val(this.childrenCount);
  };

  this.destroy = function () {
    this.$element.remove();
  };
}